onDidAcceptIncomingCall property
onDidAcceptIncomingCall and onDidRejectIncomingCall can be called even if the app is not running. This is because the app is already running when the incoming call screen is displayed for CallKit. If not called, make sure the app is calling onDidAcceptIncomingCall and onDidRejectIncomingCall in the Dart class(ex: main.dart) that is called immediately after the app is launched.
Implementation
IncomingAction? onDidAcceptIncomingCall;